@@ -15,6 +15,11 @@ pirls.mean <-
     if (missing(by)) { 
       output<-mean.input(variable=variable, weight=weight, data=data)
     } else {
+      
+      for (i in by) {
+        data[[c(i)]] <- as.factor(data[[c(i)]])
+      }
+      
       output<-ddply(data, by, function(x) mean.input(data=x, weight=weight, variable=variable))
     }
     
@@ -22,5 +27,7 @@ pirls.mean <-
       write.csv(output, file=file.path(folder, paste(name, ".csv", sep="")))
     }
     
+    class(output) <- c("intsvy.mean", "data.frame")
+    
     return(output)
   }
\ No newline at end of file
